@@ -40,8 +40,13 @@
 #include <linux/irda.h>
 #endif
 
+#include <arpa/nameser.h>
 #include <resolv.h>
 
+#if !defined (NI_MAXSERV) || !defined (NI_MAXHOST)
+#include <netdb.h>
+#endif
+
 #include <linc/linc-protocol.h>
 #include <linc/linc-connection.h>
 
